@@ -1,5 +1,5 @@
 package WebService::Blogger;
-
+$WebService::Blogger::VERSION = '0.17';
 use warnings;
 use strict;
 
@@ -9,6 +9,7 @@ use HTTP::Request::Common;
 use XML::Simple;
 use File::stat;
 use Data::Dumper;
+use Encode ();
 
 use WebService::Blogger::Blog;
 
@@ -34,8 +35,6 @@ has ua => (
 # Speed Moose up.
 __PACKAGE__->meta->make_immutable;
 
-our $VERSION = '0.16';
-
 
 sub BUILDARGS {
     ## Loads credentials from credentials file.
@@ -143,7 +142,8 @@ sub http_put {
     my $self = shift;
     my ($url, $content) = @_;
 
-    my $request = HTTP::Request->new(PUT => $url, $self->ua->default_headers, $content);
+    my $request = HTTP::Request->new(PUT => $url, $self->ua->default_headers,
+                                     Encode::encode_utf8($content));
     return $self->ua->request($request);
 }
 
@@ -175,10 +175,6 @@ __END__
 
 WebService::Blogger - Interface to Google's Blogger service
 
-=head1 VERSION
-
-Version 0.14
-
 =cut
 
 =head1 SYNOPSIS
